﻿using System;
using System.Diagnostics;
using System.IO;
using System.Net.Security;
using System.Net.Sockets;
using System.Security.Policy;
using System.Threading.Tasks;
using Microsoft.VisualStudio.TestTools.UnitTesting;
using SecureEchoTcpServer;

namespace UnitTestProject1
{
    [TestClass]
    public class UnitTest1
    {
        private const int Port = 7777;
        private static SecureEchoServer _server;

        [ClassInitialize]
        public static void Initialize(TestContext context)
        {
            Trace.AutoFlush = true;
            Trace.Listeners.Add(new TextWriterTraceListener(new FileStream("c:/temp2/echolog.txt", FileMode.Append)));
            _server = new SecureEchoServer(Port);
            Task.Run(() => _server.Start());
        }

        [ClassCleanup]
        public static void ShutDown()
        {
            _server.Stop();
        }

        [TestMethod]
        public void TestMethod()
        {
            string response = GetResponse("Hello world\n");
            Assert.AreEqual("Hello world", response);
        }

        private static string GetResponse(string request)
        {
            using (TcpClient client = new TcpClient("127.0.0.1", Port))
            {
                //Trace.WriteLine("Client connected to server");
                NetworkStream ordinaryStream = client.GetStream();

                SslStream sslStream = new SslStream(ordinaryStream, false);
                sslStream.AuthenticateAsClient("andersb.dk");

                StreamWriter writer = new StreamWriter(sslStream);
                writer.Write(request);
                writer.Flush();
                StreamReader reader = new StreamReader(sslStream);
                string response = reader.ReadLine();
                return response;
            }
        }
    }
}
